Error class

Constructors

Error({String? errorCode, String? errorDescription, String? errorReason, String? errorStep, String? errorSource})
Error.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode ↔ String?
getter/setter pair
errorDescription ↔ String?
getter/setter pair
errorReason ↔ String?
getter/setter pair
errorSource ↔ String?
getter/setter pair
errorStep ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited